@@ -1,21 +1,20 @@
 import collections
-import re
 import os
-import urllib.request
+import re
 import urllib.parse
-from distutils.errors import DistutilsSetupError
-from setuptools.dist import (
-    check_package_data,
-    check_specifier,
-)
-from setuptools import Distribution
-
-from .textwrap import DALS
-from .test_easy_install import make_nspkg_sdist
-from .test_find_packages import ensure_files
+import urllib.request
 
 import pytest
 
+from setuptools import Distribution
+from setuptools.dist import check_package_data, check_specifier
+
+from .test_easy_install import make_nspkg_sdist
+from .test_find_packages import ensure_files
+from .textwrap import DALS
+
+from distutils.errors import DistutilsSetupError
+
 
 def test_dist_fetch_build_egg(tmpdir):
     """
@@ -31,11 +30,11 @@ def test_dist_fetch_build_egg(tmpdir):
         with dist_dir.join('index.html').open('w') as fp:
             fp.write(
                 DALS(
-                    '''
+                    """
                 <!DOCTYPE html><html><body>
                 <a href="{dist_sdist}" rel="internal">{dist_sdist}</a><br/>
                 </body></html>
-                '''
+                """
                 ).format(dist_sdist=dist_sdist)
             )
 
@@ -44,16 +43,16 @@ def test_dist_fetch_build_egg(tmpdir):
     with tmpdir.join('setup.cfg').open('w') as fp:
         fp.write(
             DALS(
-                '''
+                """
             [easy_install]
             index_url = {index_url}
-            '''
+            """
             ).format(index_url=index_url)
         )
-    reqs = '''
+    reqs = """
     barbazquux-runner
     barbazquux
-    '''.split()
+    """.split()
     with tmpdir.as_cwd():
         dist = Distribution()
         dist.parse_config_files()
@@ -78,12 +77,12 @@ def test_provides_extras_deterministic_order():
     extras['b'] = ['bar']
     attrs = dict(extras_require=extras)
     dist = Distribution(attrs)
-    assert dist.metadata.provides_extras == ['a', 'b']
+    assert list(dist.metadata.provides_extras) == ['a', 'b']
     attrs['extras_require'] = collections.OrderedDict(
         reversed(list(attrs['extras_require'].items()))
     )
     dist = Distribution(attrs)
-    assert dist.metadata.provides_extras == ['b', 'a']
+    assert list(dist.metadata.provides_extras) == ['b', 'a']
 
 
 CHECK_PACKAGE_DATA_TESTS = (
@@ -116,11 +115,11 @@ CHECK_PACKAGE_DATA_TESTS = (
     # Invalid value type.
     (
         {
-            'hello': str('*.msg'),
+            'hello': '*.msg',
         },
         (
-            "\"values of 'package_data' dict\" "
-            "must be a list of strings (got '*.msg')"
+            "\"values of 'package_data' dict\" must be of type <tuple[str, ...] | list[str]>"
+            " (got '*.msg')"
         ),
     ),
     # Invalid value type (generators are single use)
@@ -129,8 +128,8 @@ CHECK_PACKAGE_DATA_TESTS = (
             'hello': (x for x in "generator"),
         },
         (
-            "\"values of 'package_data' dict\" must be a list of strings "
-            "(got <generator object"
+            "\"values of 'package_data' dict\" must be of type <tuple[str, ...] | list[str]>"
+            " (got <generator object"
         ),
     ),
 )
@@ -142,7 +141,7 @@ def test_check_package_data(package_data, expected_message):
         assert check_package_data(None, 'package_data', package_data) is None
     else:
         with pytest.raises(DistutilsSetupError, match=re.escape(expected_message)):
-            check_package_data(None, str('package_data'), package_data)
+            check_package_data(None, 'package_data', package_data)
 
 
 def test_check_specifier():
